diff --git a/Discord.Net.sln b/Discord.Net.sln
index daf902b96..9bb940d8c 100644
--- a/Discord.Net.sln
+++ b/Discord.Net.sln
@@ -1,6 +1,6 @@
Microsoft Visual Studio Solution File, Format Version 12.00
# Visual Studio 15
-VisualStudioVersion = 15.0.27130.0
+VisualStudioVersion = 15.0.27004.2009
MinimumVisualStudioVersion = 10.0.40219.1
Project("{9A19103F-16F7-4668-BE54-9A1E7A4F7556}") = "Discord.Net.Core", "src\Discord.Net.Core\Discord.Net.Core.csproj", "{91E9E7BD-75C9-4E98-84AA-2C271922E5C2}"
EndProject
@@ -22,7 +22,13 @@ Project("{9A19103F-16F7-4668-BE54-9A1E7A4F7556}") = "Discord.Net.Tests", "test\D
EndProject
Project("{9A19103F-16F7-4668-BE54-9A1E7A4F7556}") = "Discord.Net.Webhook", "src\Discord.Net.Webhook\Discord.Net.Webhook.csproj", "{9AFAB80E-D2D3-4EDB-B58C-BACA78D1EA30}"
EndProject
-Project("{FAE04EC0-301F-11D3-BF4B-00C04F79EFBC}") = "Discord.Net.Analyzers", "src\Discord.Net.Analyzers\Discord.Net.Analyzers.csproj", "{BBA8E7FB-C834-40DC-822F-B112CB7F0140}"
+Project("{9A19103F-16F7-4668-BE54-9A1E7A4F7556}") = "Discord.Net.Analyzers", "src\Discord.Net.Analyzers\Discord.Net.Analyzers.csproj", "{BBA8E7FB-C834-40DC-822F-B112CB7F0140}"
+EndProject
+Project("{2150E333-8FDC-42A3-9474-1A3956D46DE8}") = "Samples", "Samples", "{BB59D5B5-E7B0-4BF4-8F82-D14431B2799B}"
+EndProject
+Project("{FAE04EC0-301F-11D3-BF4B-00C04F79EFBC}") = "01_basic_ping_bot", "samples\01_basic_ping_bot\01_basic_ping_bot.csproj", "{F2FF84FB-F6AD-47E5-9EE5-18206CAE136E}"
+EndProject
+Project("{9A19103F-16F7-4668-BE54-9A1E7A4F7556}") = "02_commands_framework", "samples\02_commands_framework\02_commands_framework.csproj", "{4E1F1F40-B1DD-40C9-A4B1-A2046A4C9C76}"
EndProject
Global
GlobalSection(SolutionConfigurationPlatforms) = preSolution
@@ -130,6 +136,30 @@ Global
{BBA8E7FB-C834-40DC-822F-B112CB7F0140}.Release|x64.Build.0 = Release|Any CPU
{BBA8E7FB-C834-40DC-822F-B112CB7F0140}.Release|x86.ActiveCfg = Release|Any CPU
{BBA8E7FB-C834-40DC-822F-B112CB7F0140}.Release|x86.Build.0 = Release|Any CPU
+ {F2FF84FB-F6AD-47E5-9EE5-18206CAE136E}.Debug|Any CPU.ActiveCfg = Debug|Any CPU
+ {F2FF84FB-F6AD-47E5-9EE5-18206CAE136E}.Debug|Any CPU.Build.0 = Debug|Any CPU
+ {F2FF84FB-F6AD-47E5-9EE5-18206CAE136E}.Debug|x64.ActiveCfg = Debug|Any CPU
+ {F2FF84FB-F6AD-47E5-9EE5-18206CAE136E}.Debug|x64.Build.0 = Debug|Any CPU
+ {F2FF84FB-F6AD-47E5-9EE5-18206CAE136E}.Debug|x86.ActiveCfg = Debug|Any CPU
+ {F2FF84FB-F6AD-47E5-9EE5-18206CAE136E}.Debug|x86.Build.0 = Debug|Any CPU
+ {F2FF84FB-F6AD-47E5-9EE5-18206CAE136E}.Release|Any CPU.ActiveCfg = Release|Any CPU
+ {F2FF84FB-F6AD-47E5-9EE5-18206CAE136E}.Release|Any CPU.Build.0 = Release|Any CPU
+ {F2FF84FB-F6AD-47E5-9EE5-18206CAE136E}.Release|x64.ActiveCfg = Release|Any CPU
+ {F2FF84FB-F6AD-47E5-9EE5-18206CAE136E}.Release|x64.Build.0 = Release|Any CPU
+ {F2FF84FB-F6AD-47E5-9EE5-18206CAE136E}.Release|x86.ActiveCfg = Release|Any CPU
+ {F2FF84FB-F6AD-47E5-9EE5-18206CAE136E}.Release|x86.Build.0 = Release|Any CPU
+ {4E1F1F40-B1DD-40C9-A4B1-A2046A4C9C76}.Debug|Any CPU.ActiveCfg = Debug|Any CPU
+ {4E1F1F40-B1DD-40C9-A4B1-A2046A4C9C76}.Debug|Any CPU.Build.0 = Debug|Any CPU
+ {4E1F1F40-B1DD-40C9-A4B1-A2046A4C9C76}.Debug|x64.ActiveCfg = Debug|Any CPU
+ {4E1F1F40-B1DD-40C9-A4B1-A2046A4C9C76}.Debug|x64.Build.0 = Debug|Any CPU
+ {4E1F1F40-B1DD-40C9-A4B1-A2046A4C9C76}.Debug|x86.ActiveCfg = Debug|Any CPU
+ {4E1F1F40-B1DD-40C9-A4B1-A2046A4C9C76}.Debug|x86.Build.0 = Debug|Any CPU
+ {4E1F1F40-B1DD-40C9-A4B1-A2046A4C9C76}.Release|Any CPU.ActiveCfg = Release|Any CPU
+ {4E1F1F40-B1DD-40C9-A4B1-A2046A4C9C76}.Release|Any CPU.Build.0 = Release|Any CPU
+ {4E1F1F40-B1DD-40C9-A4B1-A2046A4C9C76}.Release|x64.ActiveCfg = Release|Any CPU
+ {4E1F1F40-B1DD-40C9-A4B1-A2046A4C9C76}.Release|x64.Build.0 = Release|Any CPU
+ {4E1F1F40-B1DD-40C9-A4B1-A2046A4C9C76}.Release|x86.ActiveCfg = Release|Any CPU
+ {4E1F1F40-B1DD-40C9-A4B1-A2046A4C9C76}.Release|x86.Build.0 = Release|Any CPU
EndGlobalSection
GlobalSection(SolutionProperties) = preSolution
HideSolutionNode = FALSE
@@ -141,6 +171,8 @@ Global
{6BDEEC08-417B-459F-9CA3-FF8BAB18CAC7} = {B0657AAE-DCC5-4FBF-8E5D-1FB578CF3012}
{9AFAB80E-D2D3-4EDB-B58C-BACA78D1EA30} = {CC3D4B1C-9DE0-448B-8AE7-F3F1F3EC5C3A}
{BBA8E7FB-C834-40DC-822F-B112CB7F0140} = {CC3D4B1C-9DE0-448B-8AE7-F3F1F3EC5C3A}
+ {F2FF84FB-F6AD-47E5-9EE5-18206CAE136E} = {BB59D5B5-E7B0-4BF4-8F82-D14431B2799B}
+ {4E1F1F40-B1DD-40C9-A4B1-A2046A4C9C76} = {BB59D5B5-E7B0-4BF4-8F82-D14431B2799B}
EndGlobalSection
GlobalSection(ExtensibilityGlobals) = postSolution
SolutionGuid = {D2404771-EEC8-45F2-9D71-F3373F6C1495}
diff --git a/samples/01_basic_ping_bot/01_basic_ping_bot.csproj b/samples/01_basic_ping_bot/01_basic_ping_bot.csproj
new file mode 100644
index 000000000..5484e3d55
--- /dev/null
+++ b/samples/01_basic_ping_bot/01_basic_ping_bot.csproj
@@ -0,0 +1,12 @@
+
+
+
+ Exe
+ netcoreapp2.0
+
+
+
+
+
+
+
diff --git a/samples/01_basic_ping_bot/Program.cs b/samples/01_basic_ping_bot/Program.cs
new file mode 100644
index 000000000..0fcc52b85
--- /dev/null
+++ b/samples/01_basic_ping_bot/Program.cs
@@ -0,0 +1,69 @@
+using System;
+using System.Threading.Tasks;
+using Discord;
+using Discord.WebSocket;
+
+namespace _01_basic_ping_bot
+{
+ // This is a minimal, barebones example of using Discord.Net
+ //
+ // If writing a bot with commands, we recommend using the Discord.Net.Commands
+ // framework, rather than handling commands yourself, like we do in this sample.
+ //
+ // You can find samples of using the command framework:
+ // - Here, under the 02_commands_framework sample
+ // - https://github.com/foxbot/DiscordBotBase - a barebones bot template
+ // - https://github.com/foxbot/patek - a more feature-filled bot, utilizing more aspects of the library
+ class Program
+ {
+ private DiscordSocketClient _client;
+
+ // Discord.Net heavily utilizes TAP for async, so we create
+ // an asynchronous context from the beginning.
+ static void Main(string[] args)
+ => new Program().MainAsync().GetAwaiter().GetResult();
+
+ public async Task MainAsync()
+ {
+ _client = new DiscordSocketClient();
+
+ _client.Log += LogAsync;
+ _client.Ready += ReadyAsync;
+ _client.MessageReceived += MessageReceivedAsync;
+
+ // Tokens should be considered secret data, and never hard-coded.
+ await _client.LoginAsync(TokenType.Bot, Environment.GetEnvironmentVariable("token"));
+ await _client.StartAsync();
+
+ // Block the program until it is closed.
+ await Task.Delay(-1);
+ }
+
+ private Task LogAsync(LogMessage log)
+ {
+ Console.WriteLine(log.ToString());
+ return Task.CompletedTask;
+ }
+
+ // The Ready event indicates that the client has opened a
+ // connection and it is now safe to access the cache.
+ private Task ReadyAsync()
+ {
+ Console.WriteLine($"{_client.CurrentUser} is connected!");
+
+ return Task.CompletedTask;
+ }
+
+ // This is not the recommmended way to write a bot - consider
+ // reading over the Commands Framework sample.
+ private async Task MessageReceivedAsync(SocketMessage message)
+ {
+ // The bot should never respond to itself.
+ if (message.Author.Id == _client.CurrentUser.Id)
+ return;
+
+ if (message.Content == "!ping")
+ await message.Channel.SendMessageAsync("pong!");
+ }
+ }
+}
diff --git a/samples/02_commands_framework/02_commands_framework.csproj b/samples/02_commands_framework/02_commands_framework.csproj
new file mode 100644
index 000000000..77fdc65e1
--- /dev/null
+++ b/samples/02_commands_framework/02_commands_framework.csproj
@@ -0,0 +1,17 @@
+
+
+
+ Exe
+ netcoreapp2.0
+
+
+
+
+
+
+
+
+
+
+
+
diff --git a/samples/02_commands_framework/Modules/PublicModule.cs b/samples/02_commands_framework/Modules/PublicModule.cs
new file mode 100644
index 000000000..f30dfd73f
--- /dev/null
+++ b/samples/02_commands_framework/Modules/PublicModule.cs
@@ -0,0 +1,63 @@
+using System.IO;
+using System.Threading.Tasks;
+using Discord;
+using Discord.Commands;
+using _02_commands_framework.Services;
+
+namespace _02_commands_framework.Modules
+{
+ // Modules must be public and inherit from an IModuleBase
+ public class PublicModule : ModuleBase
+ {
+ // Dependency Injection will fill this value in for us
+ public PictureService PictureService { get; set; }
+
+ [Command("ping")]
+ [Alias("pong", "hello")]
+ public Task PingAsync()
+ => ReplyAsync("pong!");
+
+ [Command("cat")]
+ public async Task CatAsync()
+ {
+ // Get a stream containing an image of a cat
+ var stream = await PictureService.GetCatPictureAsync();
+ // Streams must be seeked to their beginning before being uploaded!
+ stream.Seek(0, SeekOrigin.Begin);
+ await Context.Channel.SendFileAsync(stream, "cat.png");
+ }
+
+ // Get info on a user, or the user who invoked the command if one is not specified
+ [Command("userinfo")]
+ public async Task UserInfoAsync(IUser user = null)
+ {
+ user = user ?? Context.User;
+
+ await ReplyAsync(user.ToString());
+ }
+
+ // Ban a user
+ [Command("ban")]
+ [RequireContext(ContextType.Guild)]
+ // make sure the user invoking the command can ban
+ [RequireUserPermission(GuildPermission.BanMembers)]
+ // make sure the bot itself can ban
+ [RequireBotPermission(GuildPermission.BanMembers)]
+ public async Task BanUserAsync(IGuildUser user, [Remainder] string reason = null)
+ {
+ await user.Guild.AddBanAsync(user, reason: reason);
+ await ReplyAsync("ok!");
+ }
+
+ // [Remainder] takes the rest of the command's arguments as one argument, rather than splitting every space
+ [Command("echo")]
+ public Task EchoAsync([Remainder] string text)
+ // Insert a ZWSP before the text to prevent triggering other bots!
+ => ReplyAsync('\u200B' + text);
+
+ // 'params' will parse space-separated elements into a list
+ [Command("list")]
+ public Task ListAsync(params string[] objects)
+ => ReplyAsync("You listed: " + string.Join("; ", objects));
+ }
+}
diff --git a/samples/02_commands_framework/Program.cs b/samples/02_commands_framework/Program.cs
new file mode 100644
index 000000000..3fed652d3
--- /dev/null
+++ b/samples/02_commands_framework/Program.cs
@@ -0,0 +1,60 @@
+using System;
+using System.Net.Http;
+using System.Threading.Tasks;
+using Microsoft.Extensions.DependencyInjection;
+using Discord;
+using Discord.WebSocket;
+using Discord.Commands;
+using _02_commands_framework.Services;
+
+namespace _02_commands_framework
+{
+ // This is a minimal example of using Discord.Net's command
+ // framework - by no means does it show everything the framework
+ // is capable of.
+ //
+ // You can find samples of using the command framework:
+ // - Here, under the 02_commands_framework sample
+ // - https://github.com/foxbot/DiscordBotBase - a barebones bot template
+ // - https://github.com/foxbot/patek - a more feature-filled bot, utilizing more aspects of the library
+ class Program
+ {
+ static void Main(string[] args)
+ => new Program().MainAsync().GetAwaiter().GetResult();
+
+ public async Task MainAsync()
+ {
+ var services = ConfigureServices();
+
+ var client = services.GetRequiredService();
+
+ client.Log += LogAsync;
+ services.GetRequiredService().Log += LogAsync;
+
+ await client.LoginAsync(TokenType.Bot, Environment.GetEnvironmentVariable("token"));
+ await client.StartAsync();
+
+ await services.GetRequiredService().InitializeAsync();
+
+ await Task.Delay(-1);
+ }
+
+ private Task LogAsync(LogMessage log)
+ {
+ Console.WriteLine(log.ToString());
+
+ return Task.CompletedTask;
+ }
+
+ private IServiceProvider ConfigureServices()
+ {
+ return new ServiceCollection()
+ .AddSingleton()
+ .AddSingleton()
+ .AddSingleton()
+ .AddSingleton()
+ .AddSingleton()
+ .BuildServiceProvider();
+ }
+ }
+}
diff --git a/samples/02_commands_framework/Services/CommandHandlingService.cs b/samples/02_commands_framework/Services/CommandHandlingService.cs
new file mode 100644
index 000000000..fc253eed3
--- /dev/null
+++ b/samples/02_commands_framework/Services/CommandHandlingService.cs
@@ -0,0 +1,49 @@
+using System;
+using System.Reflection;
+using System.Threading.Tasks;
+using Microsoft.Extensions.DependencyInjection;
+using Discord;
+using Discord.Commands;
+using Discord.WebSocket;
+
+namespace _02_commands_framework.Services
+{
+ public class CommandHandlingService
+ {
+ private readonly CommandService _commands;
+ private readonly DiscordSocketClient _discord;
+ private readonly IServiceProvider _services;
+
+ public CommandHandlingService(IServiceProvider services)
+ {
+ _commands = services.GetRequiredService();
+ _discord = services.GetRequiredService();
+ _services = services;
+
+ _discord.MessageReceived += MessageReceivedAsync;
+ }
+
+ public async Task InitializeAsync()
+ {
+ await _commands.AddModulesAsync(Assembly.GetEntryAssembly(), _services);
+ }
+
+ public async Task MessageReceivedAsync(SocketMessage rawMessage)
+ {
+ // Ignore system messages, or messages from other bots
+ if (!(rawMessage is SocketUserMessage message)) return;
+ if (message.Source != MessageSource.User) return;
+
+ // This value holds the offset where the prefix ends
+ var argPos = 0;
+ if (!message.HasMentionPrefix(_discord.CurrentUser, ref argPos)) return;
+
+ var context = new SocketCommandContext(_discord, message);
+ var result = await _commands.ExecuteAsync(context, argPos, _services);
+
+ if (result.Error.HasValue &&
+ result.Error.Value != CommandError.UnknownCommand) // it's bad practice to send 'unknown command' errors
+ await context.Channel.SendMessageAsync(result.ToString());
+ }
+ }
+}
diff --git a/samples/02_commands_framework/Services/PictureService.cs b/samples/02_commands_framework/Services/PictureService.cs
new file mode 100644
index 000000000..dda818cc3
--- /dev/null
+++ b/samples/02_commands_framework/Services/PictureService.cs
@@ -0,0 +1,20 @@
+using System.IO;
+using System.Net.Http;
+using System.Threading.Tasks;
+
+namespace _02_commands_framework.Services
+{
+ public class PictureService
+ {
+ private readonly HttpClient _http;
+
+ public PictureService(HttpClient http)
+ => _http = http;
+
+ public async Task GetCatPictureAsync()
+ {
+ var resp = await _http.GetAsync("https://cataas.com/cat");
+ return await resp.Content.ReadAsStreamAsync();
+ }
+ }
+}
diff --git a/src/Discord.Net.Commands/Attributes/CommandAttribute.cs b/src/Discord.Net.Commands/Attributes/CommandAttribute.cs
index cce82101b..6cc46a792 100644
--- a/src/Discord.Net.Commands/Attributes/CommandAttribute.cs
+++ b/src/Discord.Net.Commands/Attributes/CommandAttribute.cs
@@ -14,6 +14,7 @@ namespace Discord.Commands
/// Specifies the of the command. This affects how the command is executed.
///
public RunMode RunMode { get; set; } = RunMode.Default;
+ public bool? IgnoreExtraArgs { get; set; }
///
public CommandAttribute()
diff --git a/src/Discord.Net.Commands/Builders/CommandBuilder.cs b/src/Discord.Net.Commands/Builders/CommandBuilder.cs
index 7dcba8362..3f1ca883a 100644
--- a/src/Discord.Net.Commands/Builders/CommandBuilder.cs
+++ b/src/Discord.Net.Commands/Builders/CommandBuilder.cs
@@ -21,6 +21,7 @@ namespace Discord.Commands.Builders
public string PrimaryAlias { get; set; }
public RunMode RunMode { get; set; }
public int Priority { get; set; }
+ public bool IgnoreExtraArgs { get; set; }
public IReadOnlyList Preconditions => _preconditions;
public IReadOnlyList Parameters => _parameters;
diff --git a/src/Discord.Net.Commands/Builders/ModuleClassBuilder.cs b/src/Discord.Net.Commands/Builders/ModuleClassBuilder.cs
index cbeb6bffd..f5b005b29 100644
--- a/src/Discord.Net.Commands/Builders/ModuleClassBuilder.cs
+++ b/src/Discord.Net.Commands/Builders/ModuleClassBuilder.cs
@@ -158,6 +158,7 @@ namespace Discord.Commands
builder.AddAliases(command.Text);
builder.RunMode = command.RunMode;
builder.Name = builder.Name ?? command.Text;
+ builder.IgnoreExtraArgs = command.IgnoreExtraArgs ?? service._ignoreExtraArgs;
break;
case NameAttribute name:
builder.Name = name.Text;
diff --git a/src/Discord.Net.Commands/CommandParser.cs b/src/Discord.Net.Commands/CommandParser.cs
index 573b04d54..02011bd9f 100644
--- a/src/Discord.Net.Commands/CommandParser.cs
+++ b/src/Discord.Net.Commands/CommandParser.cs
@@ -14,7 +14,7 @@ namespace Discord.Commands
QuotedParameter
}
- public static async Task ParseArgsAsync(CommandInfo command, ICommandContext context, bool ignoreExtraArgs, IServiceProvider services, string input, int startPos)
+ public static async Task ParseArgsAsync(CommandInfo command, ICommandContext context, IServiceProvider services, string input, int startPos)
{
ParameterInfo curParam = null;
StringBuilder argBuilder = new StringBuilder(input.Length);
@@ -110,7 +110,7 @@ namespace Discord.Commands
{
if (curParam == null)
{
- if (ignoreExtraArgs)
+ if (command.IgnoreExtraArgs)
break;
else
return ParseResult.FromError(CommandError.BadArgCount, "The input text has too many parameters.");
diff --git a/src/Discord.Net.Commands/CommandServiceConfig.cs b/src/Discord.Net.Commands/CommandServiceConfig.cs
index 5d33ddf11..f06289a8d 100644
--- a/src/Discord.Net.Commands/CommandServiceConfig.cs
+++ b/src/Discord.Net.Commands/CommandServiceConfig.cs
@@ -37,11 +37,5 @@ namespace Discord.Commands
/// Gets or sets whether extra parameters should be ignored.
///
public bool IgnoreExtraArgs { get; set; } = false;
-
- ///// Gets or sets the to use.
- //public IServiceProvider ServiceProvider { get; set; } = null;
-
- ///// Gets or sets a factory function for the to use.
- //public Func ServiceProviderFactory { get; set; } = null;
}
}
diff --git a/src/Discord.Net.Commands/Info/CommandInfo.cs b/src/Discord.Net.Commands/Info/CommandInfo.cs
index 65581dcc3..3f4429bad 100644
--- a/src/Discord.Net.Commands/Info/CommandInfo.cs
+++ b/src/Discord.Net.Commands/Info/CommandInfo.cs
@@ -61,6 +61,10 @@ namespace Discord.Commands
///
public bool HasVarArgs { get; }
///
+ /// Indicates whether extra arguments should be ignored for this command.
+ ///
+ public bool IgnoreExtraArgs { get; }
+ ///
/// Gets the that is being used for the command.
///
public RunMode RunMode { get; }
@@ -111,6 +115,7 @@ namespace Discord.Commands
Parameters = builder.Parameters.Select(x => x.Build(this)).ToImmutableArray();
HasVarArgs = builder.Parameters.Count > 0 ? builder.Parameters[builder.Parameters.Count - 1].IsMultiple : false;
+ IgnoreExtraArgs = builder.IgnoreExtraArgs;
_action = builder.Callback;
_commandService = service;
@@ -167,7 +172,7 @@ namespace Discord.Commands
return ParseResult.FromError(preconditionResult);
string input = searchResult.Text.Substring(startIndex);
- return await CommandParser.ParseArgsAsync(this, context, _commandService._ignoreExtraArgs, services, input, 0).ConfigureAwait(false);
+ return await CommandParser.ParseArgsAsync(this, context, services, input, 0).ConfigureAwait(false);
}
public Task ExecuteAsync(ICommandContext context, ParseResult parseResult, IServiceProvider services)
diff --git a/src/Discord.Net.Commands/Info/ModuleInfo.cs b/src/Discord.Net.Commands/Info/ModuleInfo.cs
index 54442afb7..7c144599b 100644
--- a/src/Discord.Net.Commands/Info/ModuleInfo.cs
+++ b/src/Discord.Net.Commands/Info/ModuleInfo.cs
@@ -22,8 +22,6 @@ namespace Discord.Commands
public ModuleInfo Parent { get; }
public bool IsSubmodule => Parent != null;
- //public TypeInfo TypeInfo { get; }
-
internal ModuleInfo(ModuleBuilder builder, CommandService service, IServiceProvider services, ModuleInfo parent = null)
{
Service = service;
@@ -34,8 +32,6 @@ namespace Discord.Commands
Group = builder.Group;
Parent = parent;
- //TypeInfo = builder.TypeInfo;
-
Aliases = BuildAliases(builder, service).ToImmutableArray();
Commands = builder.Commands.Select(x => x.Build(this, service)).ToImmutableArray();
Preconditions = BuildPreconditions(builder).ToImmutableArray();
diff --git a/src/Discord.Net.Commands/Readers/ChannelTypeReader.cs b/src/Discord.Net.Commands/Readers/ChannelTypeReader.cs
index 3136eb2cb..cd7a9d744 100644
--- a/src/Discord.Net.Commands/Readers/ChannelTypeReader.cs
+++ b/src/Discord.Net.Commands/Readers/ChannelTypeReader.cs
@@ -1,4 +1,4 @@
-using System;
+using System;
using System.Collections.Generic;
using System.Globalization;
using System.Linq;
@@ -6,7 +6,7 @@ using System.Threading.Tasks;
namespace Discord.Commands
{
- internal class ChannelTypeReader : TypeReader
+ public class ChannelTypeReader : TypeReader
where T : class, IChannel
{
public override async Task ReadAsync(ICommandContext context, string input, IServiceProvider services)
diff --git a/src/Discord.Net.Commands/Readers/MessageTypeReader.cs b/src/Discord.Net.Commands/Readers/MessageTypeReader.cs
index fe576c3c6..a87cfbe43 100644
--- a/src/Discord.Net.Commands/Readers/MessageTypeReader.cs
+++ b/src/Discord.Net.Commands/Readers/MessageTypeReader.cs
@@ -1,10 +1,10 @@
-using System;
+using System;
using System.Globalization;
using System.Threading.Tasks;
namespace Discord.Commands
{
- internal class MessageTypeReader : TypeReader
+ public class MessageTypeReader : TypeReader
where T : class, IMessage
{
public override async Task ReadAsync(ICommandContext context, string input, IServiceProvider services)
diff --git a/src/Discord.Net.Commands/Readers/RoleTypeReader.cs b/src/Discord.Net.Commands/Readers/RoleTypeReader.cs
index 838ff32b4..c199033fa 100644
--- a/src/Discord.Net.Commands/Readers/RoleTypeReader.cs
+++ b/src/Discord.Net.Commands/Readers/RoleTypeReader.cs
@@ -6,7 +6,7 @@ using System.Threading.Tasks;
namespace Discord.Commands
{
- internal class RoleTypeReader : TypeReader
+ public class RoleTypeReader : TypeReader
where T : class, IRole
{
public override Task ReadAsync(ICommandContext context, string input, IServiceProvider services)
diff --git a/src/Discord.Net.Commands/Readers/UserTypeReader.cs b/src/Discord.Net.Commands/Readers/UserTypeReader.cs
index 7a9e177ff..7feab50ad 100644
--- a/src/Discord.Net.Commands/Readers/UserTypeReader.cs
+++ b/src/Discord.Net.Commands/Readers/UserTypeReader.cs
@@ -7,7 +7,7 @@ using System.Threading.Tasks;
namespace Discord.Commands
{
- internal class UserTypeReader : TypeReader
+ public class UserTypeReader : TypeReader
where T : class, IUser
{
public override async Task ReadAsync(ICommandContext context, string input, IServiceProvider services)
diff --git a/src/Discord.Net.Commands/Results/TypeReaderResult.cs b/src/Discord.Net.Commands/Results/TypeReaderResult.cs
index 49dd96b63..ea475bb46 100644
--- a/src/Discord.Net.Commands/Results/TypeReaderResult.cs
+++ b/src/Discord.Net.Commands/Results/TypeReaderResult.cs
@@ -2,6 +2,7 @@ using System;
using System.Collections.Generic;
using System.Collections.Immutable;
using System.Diagnostics;
+using System.Linq;
namespace Discord.Commands
{
@@ -33,6 +34,9 @@ namespace Discord.Commands
///
public bool IsSuccess => !Error.HasValue;
+ public object BestMatch => IsSuccess
+ ? (Values.Count == 1 ? Values.Single().Value : Values.OrderByDescending(v => v.Score).First().Value)
+ : throw new InvalidOperationException("TypeReaderResult was not successful.");
private TypeReaderResult(IReadOnlyCollection values, CommandError? error, string errorReason)
{
diff --git a/src/Discord.Net.Core/CDN.cs b/src/Discord.Net.Core/CDN.cs
index bd83b64e9..1b75d0633 100644
--- a/src/Discord.Net.Core/CDN.cs
+++ b/src/Discord.Net.Core/CDN.cs
@@ -65,6 +65,8 @@ namespace Discord
///
public static string GetSpotifyAlbumArtUrl(string albumArtId)
=> $"https://i.scdn.co/image/{albumArtId}";
+ public static string GetSpotifyDirectUrl(string trackId)
+ => $"https://open.spotify.com/track/{trackId}";
private static string FormatToExtension(ImageFormat format, string imageId)
{
diff --git a/src/Discord.Net.Core/Entities/Invites/IInvite.cs b/src/Discord.Net.Core/Entities/Invites/IInvite.cs
index 1be65face..62e4a4bfc 100644
--- a/src/Discord.Net.Core/Entities/Invites/IInvite.cs
+++ b/src/Discord.Net.Core/Entities/Invites/IInvite.cs
@@ -41,10 +41,13 @@ namespace Discord
/// Gets the name of the guild this invite is linked to.
///
string GuildName { get; }
-
///
- /// Accepts this invite and joins the target guild. This will fail on bot accounts.
+ /// Gets the approximated count of online members in the guild.
+ ///
+ int? PresenceCount { get; }
+ ///
+ /// Gets the approximated count of total members in the guild.
///
- Task AcceptAsync(RequestOptions options = null);
+ int? MemberCount { get; }
}
}
diff --git a/src/Discord.Net.Core/Entities/Messages/Embed.cs b/src/Discord.Net.Core/Entities/Messages/Embed.cs
index 1f2846f2e..b10473c00 100644
--- a/src/Discord.Net.Core/Entities/Messages/Embed.cs
+++ b/src/Discord.Net.Core/Entities/Messages/Embed.cs
@@ -76,7 +76,18 @@ namespace Discord
///
/// Gets the total length of all embed properties.
///
- public int Length => Title?.Length + Author?.Name?.Length + Description?.Length + Footer?.Text?.Length + Fields.Sum(f => f.Name.Length + f.Value.ToString().Length) ?? 0;
+ public int Length
+ {
+ get
+ {
+ int titleLength = Title?.Length ?? 0;
+ int authorLength = Author?.Name?.Length ?? 0;
+ int descriptionLength = Description?.Length ?? 0;
+ int footerLength = Footer?.Text?.Length ?? 0;
+ int fieldSum = Fields.Sum(f => f.Name?.Length + f.Value?.ToString().Length) ?? 0;
+ return titleLength + authorLength + descriptionLength + footerLength + fieldSum;
+ }
+ }
///
/// Gets the title of the embed.
diff --git a/src/Discord.Net.Core/IDiscordClient.cs b/src/Discord.Net.Core/IDiscordClient.cs
index 344dff6d5..92aee2b08 100644
--- a/src/Discord.Net.Core/IDiscordClient.cs
+++ b/src/Discord.Net.Core/IDiscordClient.cs
@@ -56,7 +56,7 @@ namespace Discord
Task> GetGuildsAsync(CacheMode mode = CacheMode.AllowDownload, RequestOptions options = null);
Task CreateGuildAsync(string name, IVoiceRegion region, Stream jpegIcon = null, RequestOptions options = null);
- Task GetInviteAsync(string inviteId, RequestOptions options = null);
+ Task GetInviteAsync(string inviteId, bool withCount = false, RequestOptions options = null);
Task GetUserAsync(ulong id, CacheMode mode = CacheMode.AllowDownload, RequestOptions options = null);
Task GetUserAsync(string username, string discriminator, RequestOptions options = null);
diff --git a/src/Discord.Net.Rest/API/Common/Invite.cs b/src/Discord.Net.Rest/API/Common/Invite.cs
index 67a318c5a..1b35da870 100644
--- a/src/Discord.Net.Rest/API/Common/Invite.cs
+++ b/src/Discord.Net.Rest/API/Common/Invite.cs
@@ -1,4 +1,4 @@
-#pragma warning disable CS1591
+#pragma warning disable CS1591
using Newtonsoft.Json;
namespace Discord.API
@@ -11,5 +11,9 @@ namespace Discord.API
public InviteGuild Guild { get; set; }
[JsonProperty("channel")]
public InviteChannel Channel { get; set; }
+ [JsonProperty("approximate_presence_count")]
+ public Optional PresenceCount { get; set; }
+ [JsonProperty("approximate_member_count")]
+ public Optional MemberCount { get; set; }
}
}
diff --git a/src/Discord.Net.Rest/API/Rest/GetInviteParams.cs b/src/Discord.Net.Rest/API/Rest/GetInviteParams.cs
new file mode 100644
index 000000000..cb8d8f7fe
--- /dev/null
+++ b/src/Discord.Net.Rest/API/Rest/GetInviteParams.cs
@@ -0,0 +1,7 @@
+namespace Discord.API.Rest
+{
+ internal class GetInviteParams
+ {
+ public Optional WithCounts { get; set; }
+ }
+}
diff --git a/src/Discord.Net.Rest/BaseDiscordClient.cs b/src/Discord.Net.Rest/BaseDiscordClient.cs
index db04b036e..44d19d018 100644
--- a/src/Discord.Net.Rest/BaseDiscordClient.cs
+++ b/src/Discord.Net.Rest/BaseDiscordClient.cs
@@ -164,7 +164,7 @@ namespace Discord.Rest
=> Task.FromResult>(ImmutableArray.Create());
///
- Task IDiscordClient.GetInviteAsync(string inviteId, RequestOptions options)
+ Task IDiscordClient.GetInviteAsync(string inviteId, bool withCount, RequestOptions options)
=> Task.FromResult(null);
///
diff --git a/src/Discord.Net.Rest/ClientHelper.cs b/src/Discord.Net.Rest/ClientHelper.cs
index 155430a7f..24cabe4d4 100644
--- a/src/Discord.Net.Rest/ClientHelper.cs
+++ b/src/Discord.Net.Rest/ClientHelper.cs
@@ -52,12 +52,16 @@ namespace Discord.Rest
return models.Select(x => RestConnection.Create(x)).ToImmutableArray();
}
- public static async Task GetInviteAsync(BaseDiscordClient client,
- string inviteId, RequestOptions options)
+ public static async Task GetInviteAsync(BaseDiscordClient client,
+ string inviteId, bool withCount, RequestOptions options)
{
- var model = await client.ApiClient.GetInviteAsync(inviteId, options).ConfigureAwait(false);
+ var args = new GetInviteParams
+ {
+ WithCounts = withCount
+ };
+ var model = await client.ApiClient.GetInviteAsync(inviteId, args, options).ConfigureAwait(false);
if (model != null)
- return RestInvite.Create(client, null, null, model);
+ return RestInviteMetadata.Create(client, null, null, model);
return null;
}
diff --git a/src/Discord.Net.Rest/DiscordRestApiClient.cs b/src/Discord.Net.Rest/DiscordRestApiClient.cs
index 8ffe7dbf9..c59fd0e42 100644
--- a/src/Discord.Net.Rest/DiscordRestApiClient.cs
+++ b/src/Discord.Net.Rest/DiscordRestApiClient.cs
@@ -638,7 +638,7 @@ namespace Discord.API
ulong afterUserId = args.AfterUserId.GetValueOrDefault(0);
var ids = new BucketIds(channelId: channelId);
- Expression> endpoint = () => $"channels/{channelId}/messages/{messageId}/reactions/{emoji}";
+ Expression> endpoint = () => $"channels/{channelId}/messages/{messageId}/reactions/{emoji}?limit={limit}&after={afterUserId}";
return await SendAsync>("GET", endpoint, ids, options: options).ConfigureAwait(false);
}
public async Task AckMessageAsync(ulong channelId, ulong messageId, RequestOptions options = null)
@@ -909,7 +909,7 @@ namespace Discord.API
}
//Guild Invites
- public async Task GetInviteAsync(string inviteId, RequestOptions options = null)
+ public async Task GetInviteAsync(string inviteId, GetInviteParams args, RequestOptions options = null)
{
Preconditions.NotNullOrEmpty(inviteId, nameof(inviteId));
options = RequestOptions.CreateOrClone(options);
@@ -922,9 +922,11 @@ namespace Discord.API
if (index >= 0)
inviteId = inviteId.Substring(index + 1);
+ var withCounts = args.WithCounts.GetValueOrDefault(false);
+
try
{
- return await SendAsync("GET", () => $"invites/{inviteId}", new BucketIds(), options: options).ConfigureAwait(false);
+ return await SendAsync("GET", () => $"invites/{inviteId}?with_counts={withCounts}", new BucketIds(), options: options).ConfigureAwait(false);
}
catch (HttpException ex) when (ex.HttpCode == HttpStatusCode.NotFound) { return null; }
}
@@ -962,13 +964,6 @@ namespace Discord.API
return await SendAsync("DELETE", () => $"invites/{inviteId}", new BucketIds(), options: options).ConfigureAwait(false);
}
- public async Task AcceptInviteAsync(string inviteId, RequestOptions options = null)
- {
- Preconditions.NotNullOrEmpty(inviteId, nameof(inviteId));
- options = RequestOptions.CreateOrClone(options);
-
- await SendAsync("POST", () => $"invites/{inviteId}", new BucketIds(), options: options).ConfigureAwait(false);
- }
//Guild Members
public async Task GetGuildMemberAsync(ulong guildId, ulong userId, RequestOptions options = null)
diff --git a/src/Discord.Net.Rest/DiscordRestClient.cs b/src/Discord.Net.Rest/DiscordRestClient.cs
index 6092e008c..3a19dd1a5 100644
--- a/src/Discord.Net.Rest/DiscordRestClient.cs
+++ b/src/Discord.Net.Rest/DiscordRestClient.cs
@@ -52,10 +52,10 @@ namespace Discord.Rest
public Task> GetConnectionsAsync(RequestOptions options = null)
=> ClientHelper.GetConnectionsAsync(this, options);
-
- public Task GetInviteAsync(string inviteId, RequestOptions options = null)
- => ClientHelper.GetInviteAsync(this, inviteId, options);
-
+
+ public Task GetInviteAsync(string inviteId, bool withCount = false, RequestOptions options = null)
+ => ClientHelper.GetInviteAsync(this, inviteId, withCount, options);
+
public Task GetGuildAsync(ulong id, RequestOptions options = null)
=> ClientHelper.GetGuildAsync(this, id, options);
public Task GetGuildEmbedAsync(ulong id, RequestOptions options = null)
@@ -123,9 +123,8 @@ namespace Discord.Rest
async Task> IDiscordClient.GetConnectionsAsync(RequestOptions options)
=> await GetConnectionsAsync(options).ConfigureAwait(false);
- ///
- async Task IDiscordClient.GetInviteAsync(string inviteId, RequestOptions options)
- => await GetInviteAsync(inviteId, options).ConfigureAwait(false);
+ async Task IDiscordClient.GetInviteAsync(string inviteId, bool withCount, RequestOptions options)
+ => await GetInviteAsync(inviteId, withCount, options).ConfigureAwait(false);
///
async Task IDiscordClient.GetGuildAsync(ulong id, CacheMode mode, RequestOptions options)
diff --git a/src/Discord.Net.Rest/Entities/Invites/InviteHelper.cs b/src/Discord.Net.Rest/Entities/Invites/InviteHelper.cs
index 80a49e34e..ebcd93777 100644
--- a/src/Discord.Net.Rest/Entities/Invites/InviteHelper.cs
+++ b/src/Discord.Net.Rest/Entities/Invites/InviteHelper.cs
@@ -1,14 +1,9 @@
-using System.Threading.Tasks;
+using System.Threading.Tasks;
namespace Discord.Rest
{
internal static class InviteHelper
{
- public static async Task AcceptAsync(IInvite invite, BaseDiscordClient client,
- RequestOptions options)
- {
- await client.ApiClient.AcceptInviteAsync(invite.Code, options).ConfigureAwait(false);
- }
public static async Task DeleteAsync(IInvite invite, BaseDiscordClient client,
RequestOptions options)
{
diff --git a/src/Discord.Net.Rest/Entities/Invites/RestInvite.cs b/src/Discord.Net.Rest/Entities/Invites/RestInvite.cs
index 62fdaeaba..4ada0ffe2 100644
--- a/src/Discord.Net.Rest/Entities/Invites/RestInvite.cs
+++ b/src/Discord.Net.Rest/Entities/Invites/RestInvite.cs
@@ -1,6 +1,7 @@
using System;
using System.Diagnostics;
using System.Threading.Tasks;
+using Discord.API.Rest;
using Model = Discord.API.Invite;
namespace Discord.Rest
@@ -13,6 +14,10 @@ namespace Discord.Rest
///
public string GuildName { get; private set; }
///
+ public int? PresenceCount { get; private set; }
+ ///
+ public int? MemberCount { get; private set; }
+ ///
public ulong ChannelId { get; private set; }
///
public ulong GuildId { get; private set; }
@@ -42,20 +47,22 @@ namespace Discord.Rest
ChannelId = model.Channel.Id;
GuildName = model.Guild.Name;
ChannelName = model.Channel.Name;
+ MemberCount = model.MemberCount.IsSpecified ? model.MemberCount.Value : null;
+ PresenceCount = model.PresenceCount.IsSpecified ? model.PresenceCount.Value : null;
}
///
public async Task UpdateAsync(RequestOptions options = null)
{
- var model = await Discord.ApiClient.GetInviteAsync(Code, options).ConfigureAwait(false);
+ var args = new GetInviteParams();
+ if (MemberCount != null || PresenceCount != null)
+ args.WithCounts = true;
+ var model = await Discord.ApiClient.GetInviteAsync(Code, args, options).ConfigureAwait(false);
Update(model);
}
///
public Task DeleteAsync(RequestOptions options = null)
=> InviteHelper.DeleteAsync(this, Discord, options);
- ///
- public Task AcceptAsync(RequestOptions options = null)
- => InviteHelper.AcceptAsync(this, Discord, options);
public override string ToString() => Url;
private string DebuggerDisplay => $"{Url} ({GuildName} / {ChannelName})";
diff --git a/src/Discord.Net.WebSocket/BaseSocketClient.cs b/src/Discord.Net.WebSocket/BaseSocketClient.cs
index 9a47d0881..81e573e1d 100644
--- a/src/Discord.Net.WebSocket/BaseSocketClient.cs
+++ b/src/Discord.Net.WebSocket/BaseSocketClient.cs
@@ -178,8 +178,8 @@ namespace Discord.WebSocket
///
/// An awaitable containing the invite information.
///
- public Task GetInviteAsync(string inviteId, RequestOptions options = null)
- => ClientHelper.GetInviteAsync(this, inviteId, options ?? RequestOptions.Default);
+ public Task GetInviteAsync(string inviteId, bool withCount = false, RequestOptions options = null)
+ => ClientHelper.GetInviteAsync(this, inviteId, withCount, options ?? RequestOptions.Default);
// IDiscordClient
///
@@ -198,8 +198,8 @@ namespace Discord.WebSocket
=> await GetConnectionsAsync(options).ConfigureAwait(false);
///
- async Task IDiscordClient.GetInviteAsync(string inviteId, RequestOptions options)
- => await GetInviteAsync(inviteId, options).ConfigureAwait(false);
+ async Task IDiscordClient.GetInviteAsync(string inviteId, bool withCount, RequestOptions options)
+ => await GetInviteAsync(inviteId, withCount, options).ConfigureAwait(false);
///
Task IDiscordClient.GetGuildAsync(ulong id, CacheMode mode, RequestOptions options)
diff --git a/src/Discord.Net.WebSocket/DiscordShardedClient.cs b/src/Discord.Net.WebSocket/DiscordShardedClient.cs
index c65722e6f..eef1b1c90 100644
--- a/src/Discord.Net.WebSocket/DiscordShardedClient.cs
+++ b/src/Discord.Net.WebSocket/DiscordShardedClient.cs
@@ -342,8 +342,8 @@ namespace Discord.WebSocket
=> await GetConnectionsAsync().ConfigureAwait(false);
///
- async Task IDiscordClient.GetInviteAsync(string inviteId, RequestOptions options)
- => await GetInviteAsync(inviteId).ConfigureAwait(false);
+ async Task IDiscordClient.GetInviteAsync(string inviteId, bool withCount, RequestOptions options)
+ => await GetInviteAsync(inviteId, withCount, options).ConfigureAwait(false);
///
Task IDiscordClient.GetGuildAsync(ulong id, CacheMode mode, RequestOptions options)
diff --git a/src/Discord.Net.WebSocket/DiscordSocketClient.cs b/src/Discord.Net.WebSocket/DiscordSocketClient.cs
index 64f254782..d43e8a1d4 100644
--- a/src/Discord.Net.WebSocket/DiscordSocketClient.cs
+++ b/src/Discord.Net.WebSocket/DiscordSocketClient.cs
@@ -499,7 +499,7 @@ namespace Discord.WebSocket
{
await _gatewayLogger.DebugAsync("Received Dispatch (RESUMED)").ConfigureAwait(false);
- var _ = _connection.CompleteAsync();
+ _ = _connection.CompleteAsync();
//Notify the client that these guilds are available again
foreach (var guild in State.Guilds)
@@ -1108,8 +1108,10 @@ namespace Discord.WebSocket
else if (channel is SocketGroupChannel)
author = (channel as SocketGroupChannel).GetOrAddUser(data.Author.Value);
else
+ {
await UnknownChannelUserAsync(type, data.Author.Value.Id, channel.Id).ConfigureAwait(false);
- return;
+ return;
+ }
}
var msg = SocketMessage.Create(this, State, author, channel, data);
@@ -1817,8 +1819,8 @@ namespace Discord.WebSocket
=> await GetConnectionsAsync().ConfigureAwait(false);
///
- async Task IDiscordClient.GetInviteAsync(string inviteId, RequestOptions options)
- => await GetInviteAsync(inviteId).ConfigureAwait(false);
+ async Task IDiscordClient.GetInviteAsync(string inviteId, bool withCount, RequestOptions options)
+ => await GetInviteAsync(inviteId, withCount, options).ConfigureAwait(false);
///
Task IDiscordClient.GetGuildAsync(ulong id, CacheMode mode, RequestOptions options)
diff --git a/src/Discord.Net.WebSocket/Entities/Users/SocketWebhookUser.cs b/src/Discord.Net.WebSocket/Entities/Users/SocketWebhookUser.cs
index d75437c7b..b0374c85d 100644
--- a/src/Discord.Net.WebSocket/Entities/Users/SocketWebhookUser.cs
+++ b/src/Discord.Net.WebSocket/Entities/Users/SocketWebhookUser.cs
@@ -34,6 +34,7 @@ namespace Discord.WebSocket
internal SocketWebhookUser(SocketGuild guild, ulong id, ulong webhookId)
: base(guild.Discord, id)
{
+ Guild = guild;
WebhookId = webhookId;
}
internal static SocketWebhookUser Create(SocketGuild guild, ClientState state, Model model, ulong webhookId)
diff --git a/src/Discord.Net.WebSocket/Extensions/EntityExtensions.cs b/src/Discord.Net.WebSocket/Extensions/EntityExtensions.cs
index ff395a932..e8dc4b5f0 100644
--- a/src/Discord.Net.WebSocket/Extensions/EntityExtensions.cs
+++ b/src/Discord.Net.WebSocket/Extensions/EntityExtensions.cs
@@ -1,3 +1,6 @@
+using System.Collections.Immutable;
+using System.Linq;
+
namespace Discord.WebSocket
{
internal static class EntityExtensions
@@ -15,12 +18,13 @@ namespace Discord.WebSocket
{
Name = model.Name,
SessionId = model.SessionId.GetValueOrDefault(),
- SyncId = model.SyncId.Value,
+ TrackId = model.SyncId.Value,
+ TrackUrl = CDN.GetSpotifyDirectUrl(model.SyncId.Value),
AlbumTitle = albumText,
TrackTitle = model.Details.GetValueOrDefault(),
- Artists = model.State.GetValueOrDefault()?.Split(';'),
+ Artists = model.State.GetValueOrDefault()?.Split(';').Select(x=>x?.Trim()).ToImmutableArray(),
Duration = timestamps?.End - timestamps?.Start,
- AlbumArt = albumArtId != null ? CDN.GetSpotifyAlbumArtUrl(albumArtId) : null,
+ AlbumArtUrl = albumArtId != null ? CDN.GetSpotifyAlbumArtUrl(albumArtId) : null,
Type = ActivityType.Listening
};
}
diff --git a/src/Discord.Net.Core/Entities/Activities/SpotifyGame.cs b/src/Discord.Net.Core/Entities/Activities/SpotifyGame.cs
index ef75d7678..beec4eebc 100644
--- a/src/Discord.Net.Core/Entities/Activities/SpotifyGame.cs
+++ b/src/Discord.Net.Core/Entities/Activities/SpotifyGame.cs
@@ -13,11 +13,7 @@ namespace Discord
///
/// Gets the song's artist(s).
///
- public IEnumerable Artists { get; internal set; }
- ///
- /// Gets the Spotify album art of the song.
- ///
- public string AlbumArt { get; internal set; }
+ public IReadOnlyCollection Artists { get; internal set; }
///
/// Gets the Spotify album title of the song.
///
@@ -27,22 +23,34 @@ namespace Discord
///
public string TrackTitle { get; internal set; }
///
- /// Gets the synchronization ID of the song.
+ /// Gets the duration of the song.
+ ///
+ public TimeSpan? Duration { get; internal set; }
+
+ ///
+ /// Gets the track ID of the song.
///
- public string SyncId { get; internal set; }
+ public string TrackId { get; internal set; }
///
/// Gets the session ID of the song.
///
public string SessionId { get; internal set; }
+
///
- /// Gets the duration of the song.
+ /// Gets the URL of the album art.
///
- public TimeSpan? Duration { get; internal set; }
+ public string AlbumArtUrl { get; internal set; }
+ ///
+ /// Gets the direct Spotify URL of the track.
+ ///
+ public string TrackUrl { get; internal set; }
internal SpotifyGame() { }
- /// Gets the name of the song.
- public override string ToString() => Name;
+ ///
+ /// Gets the full information of the song.
+ ///
+ public override string ToString() => $"{string.Join(", ", Artists)} - {TrackTitle} ({Duration})";
private string DebuggerDisplay => $"{Name} (Spotify)";
}
}